pub struct FileStore { /* private fields */ }Expand description
A durable, file-backed message store with no in-memory message-body cache (bodies are read
from disk on every get()).
Implementations
Sourceimpl FileStore
impl FileStore
Sourcepub fn open(dir: &Path) -> Result<Self, StoreError>
pub fn open(dir: &Path) -> Result<Self, StoreError>
Open (creating if needed) a file store in dir with default options (FileStoreSync=Y).
Sourcepub fn open_with_options(
dir: &Path,
options: FileStoreOptions,
) -> Result<Self, StoreError>
pub fn open_with_options( dir: &Path, options: FileStoreOptions, ) -> Result<Self, StoreError>
Open (creating if needed) a file store in dir with explicit options (FR-025).
Sourcepub fn was_corrupted(&self) -> bool
pub fn was_corrupted(&self) -> bool
Whether a corrupt trailing record was detected and recovered on open.